@@ -17,3 +17,15 @@ sub prepare {
 }
 
 1;
+
+=head1 NAME
+
+DBIx::AnyDBD::Sybase - example Sybase.pm
+
+=head1 DESCRIPTION
+
+THIS IS AN EXAMPLE - DO NOT USE IN PRODUCTION SYSTEMS
+
+This file is meant as an example to show how DBIx::AnyDBD works.
+
+=cut
